###############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2019 XCG Consulting (http://www.xcg-consulting.fr/)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
###############################################################################
from typing import Dict

from odoo import api, fields, models


class DefaultValue(models.Model):
    """Default value for a key of the dictionary used for env var or command
    line arguments.
    """

    _name = "external_job.job_definition.default_value"
    _description = "Job Default Value"
    _rec_name = "key"

    key = fields.Char(required=True)
    value = fields.Char()
    job_def_id = fields.Many2one(
        "external_job.job_definition", required=True, ondelete="cascade"
    )

    @api.multi
    def to_dict(self) -> Dict[str, str]:
        result = {}
        for default_value in self:
            result[default_value.key] = (
                default_value.value if default_value.value else ""
            )
        return result
