##############################################################################
#
#    External Jobs, for Odoo
#    Copyright (C) 2013 XCG Consulting (http://odoo.consulting)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from odoo import fields, models


class EnvVar(models.Model):
    """This describes key/value pairs sent to extrunner when setting up an
    external job in "Extrunner" mode.
    """

    _name = "external_job.job_definition.env_var"
    _description = "Env vars sent to extrunner"

    job_def_id = fields.Many2one(
        comodel_name="external_job.job_definition",
        string="Job definition",
        ondelete="cascade",
        help="The job definition this is for.",
        readonly=True,
        required=True,
    )

    key = fields.Char(
        string="Key",
        help="Name of the variable set up for extrunner.",
        required=True,
    )

    value = fields.Char(
        string="Value",
        help=(
            "Contents of the variable set up for extrunner. May contain "
            "dynamic arguments (see legend at the bottom of the job "
            "definition form)."
        ),
        required=True,
    )
