###############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2014-2016 XCG Consulting (http://www.xcg-consulting.fr/)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
###############################################################################
import datetime
import logging

from odoo import _, api, fields, models

_logger = logging.getLogger(__name__)


class JobLog(models.Model):
    _name = "external_job.job_log"
    _description = "External job log"

    job_definition_id = fields.Many2one(
        comodel_name="external_job.job_definition",
        string="Job Definition",
        ondelete="cascade",
        required=True,
    )

    start_date = fields.Datetime(
        string="Start Date", readonly=True, default=fields.Datetime.now
    )

    end_date = fields.Datetime(string="End Date", readonly=True)

    in_file_name = fields.Char(
        string="Temporary In File Name", size=512, readonly=True
    )

    out_file_name = fields.Char(
        string="Temporary Out File Name", size=512, readonly=True
    )

    out_file = fields.Binary(
        string="Output File", related="attachment_id.datas"
    )

    filename = fields.Char(
        string="Filename", related="attachment_id.datas_fname"
    )

    stdout = fields.Text(string="StdOut", readonly=True)

    stderr = fields.Text(string="StdErr", readonly=True)

    state = fields.Selection(
        selection=[
            ("started", "Started"),
            ("done", "Done"),
            ("exception", "Exception"),
        ],
        string="State",
        default="started",
    )

    attachment_id = fields.Many2one(
        comodel_name="ir.attachment",
        string="Output File",
        help="The output of the external job.",
    )

    @api.multi
    def name_get(self):
        # TODO There might be a method that grab the lang and timezone from
        # the context and format a datetime correctly.
        res = []
        lang_model = self.env["res.lang"]
        for jlog in self:
            lang = lang_model._lang_get(self.env.lang)
            lang_format = "%s %s" % (lang.date_format, lang.time_format)

            if not lang_format:
                lang_format = "%Y-%m-%d %H:%M:%S"

            job_dtime = fields.Datetime.from_string(jlog.start_date)

            job_dtime = fields.Datetime.context_timestamp(jlog, job_dtime)

            job_dtime = datetime.datetime.strftime(job_dtime, lang_format)

            res.append((jlog.id, _("%s’s Job") % job_dtime))

        return res
